==> aws-cdk.aws-guardduty-1.61.1.tar.gz: aws-cdk.aws-guardduty-1.61.1/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-guardduty",
    "version": "1.61.1",
    "description": "The CDK Construct Library for AWS::GuardDuty",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_guardduty",
        "aws_cdk.aws_guardduty._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_guardduty._jsii": [
            "aws-guardduty@1.61.1.jsii.tgz"
        ],
        "aws_cdk.aws_guardduty": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk.core==1.61.1",
        "constructs>=3.0.4, <4.0.0",
        "jsii>=1.11.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Typing :: Typed",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved"
    ]
}
"""
)

with open("README.md") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> aws-cdk.aws-guardduty-1.95.1.tar.gz: aws-cdk.aws-guardduty-1.95.1/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-guardduty",
    "version": "1.95.1",
    "description": "The CDK Construct Library for AWS::GuardDuty",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_guardduty",
        "aws_cdk.aws_guardduty._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_guardduty._jsii": [
            "aws-guardduty@1.95.1.jsii.tgz"
        ],
        "aws_cdk.aws_guardduty": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk.core==1.95.1",
        "constructs>=3.3.69, <4.0.0",
        "jsii>=1.26.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Typing :: Typed",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved",
        "Framework :: AWS CDK",
        "Framework :: AWS CDK :: 1"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
